/***************************************************************************
                          job_deletemediumfromdatabase.h  -  description
                             -------------------
    begin                : Sat Jun 2 2001
    copyright            : (C) 2001 by Holger Sattel
    email                : hsattel@rumms.uni-mannheim.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef JOB_DELETEMEDIUMFROMDATABASE_H
#define JOB_DELETEMEDIUMFROMDATABASE_H

#include "prokyon.h"

#include "jobbase.h"

#include "lvi_medium.h"

class Job_DeleteMediumFromDatabase : public JobBase  {
public:
    Job_DeleteMediumFromDatabase(LVI_Medium *_lvi);

    int type() {
        return JOB_DELETE_MEDIUM_FROM_DATABASE;
    }

    void run();

    ~Job_DeleteMediumFromDatabase();

private:
    LVI_Medium *lvi;
};

#endif
